@@ -28,17 +28,18 @@ impl XorRand {
     /// Generates one pseudo random byte
     /// Updated in 1.3100 for better mixing
     /// Updated in 1.3200 for better distribution
+    /// Updatef in 1.3300 for better uniformity
     pub fn next_byte(&mut self) -> u8 {
         match self.state.get(0) {
             Some(first_elem) => {
                 let mut mixed = *first_elem;
                 for (i, elem) in self.state.iter().rev().enumerate() {
                     mixed = (mixed << 3 | mixed >> 5) ^ i as u8;
-                    mixed ^= mixed << 3;
+                    mixed ^= mixed >> 3;
                     mixed = (mixed << 5 | mixed >> 3) ^ *elem;
-                    mixed ^= mixed << 3;
-                    mixed = ((mixed << 5 | mixed >> 3) as u16 - 17 * i as u16) as u8;
-                    mixed ^= mixed << 3;
+                    mixed ^= mixed >> 3;
+                    mixed = ((mixed << 5 | mixed >> 3) as u16 + 17 * i as u16) as u8;
+                    mixed ^= mixed >> 3;
                     mixed = ((mixed << 3 | mixed >> 5) as u16 - 17 * *elem as u16) as u8;
                     mixed ^= mixed >> 3;
                 }
